@@ -4,6 +4,14 @@ setClass("ST",
     stopifnot(length(object@sp) >= 1)
 	stopifnot(nrow(object@time) >= 1)
 	stopifnot(nrow(object@time) == length(object@endTime))
+	# do the time zones, if set, match?
+	tz1 = attr(object@time, "tzone")
+	tz2 = attr(object@endTime, "tzone")
+	tz1.set = (!is.null(tz1) && !nchar(tz1)==0)
+	tz2.set = (!is.null(tz2) && !nchar(tz2)==0)
+	stopifnot(tz1.set == tz2.set)
+	if (tz1.set)
+		stopifnot(tz1 == tz2)
 	#stopifnot(!is.na(timeIsInterval(object)))
 	if (any(names(object@time) %in% names(object@sp)))
 		stop("name conflict: attribute names in sp and time slot must differ")
