@@ -8,7 +8,7 @@ set.seed(13579) # to make outcome a bit predictable!
 sp = cbind(x = c(0,0,1), y = c(0,1,1))
 row.names(sp) = paste("point", 1:nrow(sp), sep="")
 sp = SpatialPoints(sp)
-time = xts(1:4, as.POSIXct("2010-08-05", tz="GMT")+3600*(10:13))
+time = as.POSIXct("2010-08-05", tz="GMT")+3600*(10:13)
 m = c(10,20,30) # means for each of the 3 point locations
 mydata = rnorm(length(sp)*length(time),mean=rep(m, 4))
 IDs = paste("ID", 1:length(mydata), sep = "_")
@@ -68,7 +68,7 @@ showClass("STIDF")
 sp = expand.grid(x = 1:3, y = 1:3)
 row.names(sp) = paste("point", 1:nrow(sp), sep="")
 sp = SpatialPoints(sp)
-time = xts(1:9, as.POSIXct("2010-08-05", tz="GMT")+3600*(11:19))
+time = as.POSIXct("2010-08-05", tz="GMT")+3600*(11:19)
 m = 1:9 * 10 # means for each of the 9 point locations
 mydata = rnorm(length(sp), mean=m)
 IDs = paste("ID",1:length(mydata))
@@ -161,6 +161,7 @@ format(as(stidf, "data.frame"), tz="GMT")
 sp = cbind(x = c(0,0,1), y = c(0,1,1))
 row.names(sp) = paste("point", 1:nrow(sp), sep="")
 sp = SpatialPoints(sp)
+library(xts)
 time = xts(1:4, as.POSIXct("2010-08-05", tz="GMT")+3600*(10:13))
 mydata = rnorm(length(sp)*length(time),mean=rep(m, 4))
 IDs = paste("ID", 1:length(mydata), sep = "_")
