@@ -44,11 +44,9 @@ pts = SpatialPoints(pts)
 proj4string(pts) = "+proj=longlat +datum=WGS84"
 if (require(rgdal)) {
 pts = spTransform(pts, CRS("+proj=utm +zone=29 +datum=WGS84"))
-t = xts(1:nrow(wind), wind$time)
-timeIsInterval(t) = TRUE
 stations = 4:15
 # note the t() in:
-w = STFDF(pts, t, data.frame(values = as.vector(t(wind[stations]))))
+w = STFDF(pts, wind$time, data.frame(values = as.vector(t(wind[stations]))))
 
 library(maptools)
 m = map2SpatialLines(
@@ -76,8 +74,7 @@ covfn = function(x,y) {
 }
 
 n = 10
-tgrd = xts(1:n, seq(min(index(w)), max(index(w)), length=n))
-timeIsInterval(tgrd) = TRUE
+tgrd = seq(min(index(w)), max(index(w)), length=n)
 if (FALSE) {
 pred = krige0(sqrt(values)~1, w, STF(grd, tgrd), covfn)
 wind.pr = STFDF(grd, tgrd, data.frame(pred = pred))
